@@ -13,6 +13,3 @@ from slixmpp.plugins.xep_0059.rsm import ResultIterator, XEP_0059
 
 
 register_plugin(XEP_0059)
-
-# Retain some backwards compatibility
-xep_0059 = XEP_0059
